@@ -1,18 +1,399 @@
 #!/usr/bin/env
 #-*- coding: UTF-8 -*-
 
-version  =  0.2.2.4
-
-build_version  =  0.9.1.14920
+version  =  0.2.2.7
 
+build_version  =  0.7.1.19920
 import sys,gc,datetime,webbrowser,random,os
-os.environ["PYGAME_HIDE_SUPPORT_PROMPT"]="李导的程序"
-import xiugay as xiugou
 import calendar as cal
-import hh,tujian
 import time as t
-from pygame.locals import *
+import turtle as t1
+import tujian
 # import some modules
+
+
+def Print():
+    nb='''
+
+    .__  .__       .__                                                        
+    |  | |__| ____ |  |__   ____   ____    ____   ____   ____   ____    ____  
+    |  | |  |/ ___\|  |  \_/ __ \ /    \  / ___\ / ___\ /  _ \ /    \  / ___\ 
+    |  |_|  \  \___|   Y  \  ___/|   |  \/ /_/  > /_/  >  <_> )   |  \/ /_/  >
+    |____/__|\___  >___|  /\___  >___|  /\___  /\___  / \____/|___|  /\___  / 
+                 \/     \/     \/     \//_____//_____/             \//_____/ 
+
+    '''
+    print(nb)
+
+
+def xiugay(m1919810):
+    for i in range(2):
+        print('修改中!')
+        t.sleep(1)
+        print('修改中!!')
+        t.sleep(1)
+        print('修改中!!!')
+        t.sleep(1)
+    def tailand(haaasfsa):
+        t1.color('red','yellow')
+        t1.hideturtle()
+        t1.speed(35)
+        t1.goto(-100,-10)
+        t1.begin_fill()
+        for i in range(50):
+            t1.forward(200)
+            t1.left(170)
+        t1.end_fill()
+    def LMX(x,y,d):
+        t1.penup()
+        t1.goto(x, y)
+        t1.pendown()
+        t1.seth(60)
+        for i in range(3):
+            t1.fd(d)
+            t1.left(120)
+        t1.pu()
+        t1.goto(x, -y)
+        t1.pd()
+        t1.seth(-60)
+        for i in range(3):
+            t1.fd(d)
+            t1.right(120)
+            t1.hideturtle()
+    def yuan(r):
+        t1.pu()
+        t1.goto(-r*pow(3,0.5)/2, -r/2)
+        t1.pd()
+        t1.circle(r)
+        t1.hideturtle()
+    def sixy(x,y,r):
+        def txyuan(x,y,r):
+            t1.seth(0)
+            y = y - r
+            t1.pu()
+            t1.goto(x, y)
+            t1.pd()
+            t1.pensize(2)
+            t1.circle(r)
+            t1.pu()
+            t1.goto(x, y+3)
+            t1.pd()
+            r=r-3
+            y=y-r
+            t1.circle(r)
+        t1.color("#5daed9") 
+        txyuan(x,y,r)
+        txyuan(-x,y,r)
+        txyuan(-x,-y,r)
+        txyuan(x,-y,r)
+        txyuan(175,0,r)
+        txyuan(-175,0,r)
+        t1.hideturtle()
+    def lbx(x,y):
+        t1.penup()
+        t1.goto(x, y)
+        t1.pendown()
+        for i in range(6):
+            t1.fd(180)
+            t1.left(60)
+        t1.hideturtle()
+    def yue(x,y,r):
+        y=y-r
+        t1.penup()
+        t1.goto(x,y)
+        t1.pendown() 
+        t1.circle(r)
+        t1.circle(r-10)
+        t1.hideturtle()
+    def xingzuo(r,c,h):
+        t1.penup()
+        t1.pencolor("#fdcfad")
+        t1.goto(-10,-10)
+        t1.seth(-45)
+        t1.fd(r)
+        t1.pendown()
+        xz=['♒','♓','♈','♉','♌','♍','♎','♏','♊','♋','♐','♑']
+        for i in range(12):
+            t1.write(xz[(i+h)%12],font=("", c, ""))
+            t1.penup()
+            t1.right(90)
+            t1.circle(-r, 30)
+            t1.left(90)
+            t1.pendown()
+        t1.hideturtle()
+    def xingdui(r):
+        for i in range(1,5):
+            te=3
+            t1.penup()
+            t1.goto(0, 0)
+            t1.seth(i * 90)
+            t1.pendown()
+            t1.right(22.5)
+            t1.fd(r)
+            if i==1:
+                t1.goto(0,3*r-te)
+                t1.goto(0,0)
+                t1.seth(i * 90 + 22.5)
+                t1.fd(r)
+                t1.goto(0,3*r-te)
+            elif i==2:
+                t1.goto(-3*r+te,0)
+                t1.goto(0,0)
+                t1.seth(i*90+22.5)
+                t1.fd(r)
+                t1.goto(-3*r+te,0)
+            elif i==3:
+                t1.goto(0,-3*r+te)
+                t1.goto(0,0)
+                t1.seth(i*90+22.5)
+                t1.fd(r)
+                t1.goto(0,-3*r+te)
+            else:
+                t1.goto(3*r+te,0)
+                t1.goto(0,0)
+                t1.seth(i*90+22.5)
+                t1.fd(r)
+                t1.goto(3*r+te,0)
+            t1.hideturtle()
+        x=pow(((2*r)**2)/2,0.5)-8
+        for i in range(1,5):
+            t1.pu()
+            t1.goto(0, 0)
+            t1.seth(i * 90)
+            t1.pendown()
+            t1.right(22.5)
+            t1.fd(r)
+            if i==1:
+                t1.goto(x,x)
+                t1.goto(0,0)
+                t1.right(45)
+                t1.fd(r)
+                t1.goto(x,x)
+            elif i==2:
+                t1.goto(-x,x)
+                t1.goto(0, 0)
+                t1.right(45)
+                t1.fd(r)
+                t1.goto(-x,x)
+            elif i==3:
+                t1.goto(-x,-x)
+                t1.goto(0,0)
+                t1.right(45)
+                t1.fd(r)
+                t1.goto(-x,-x)
+            else:
+                t1.goto(x,-x)
+                t1.goto(0,0)
+                t1.right(45)
+                t1.fd(r)
+                t1.goto(x,-x)
+            t1.hideturtle()
+    def lx(rd,l,q,j):
+        def Skip(step):
+            t1.pu()
+            t1.fd(step)
+            t1.pd()
+        CLA=['yellow','#7ecff1','black']
+        for a in range(l):
+            t1.pu()
+            t1.goto(0,0)
+            t1.pendown()
+            degree=-360/l*a+q
+            t1.seth(degree)
+            Skip(rd)
+            t1.begin_fill()
+            t1.fillcolor(CLA[j])
+            t1.pencolor(CLA[j])
+            t1.right(30)
+            t1.fd(25)        
+            LZ=[60,120,60]
+            for i in range(3):
+                t1.left(LZ[i])
+                t1.fd(25)
+            t1.end_fill()
+        t1.hideturtle()
+    def stars(m):
+        CLQ=['yellow','#7ecff1']
+        for i in range(m):
+            a=random.uniform(-m*2,m*2)
+            b=random.uniform(-m*2,m*2)
+            t1.begin_fill()
+            t1.penup()
+            t1.goto(a,b)
+            t1.pendown()
+            t1.speed(900)
+            t1.fillcolor(CLQ[m%2])
+            t1.pencolor(CLQ[m%2])
+            t1.circle(m/200)
+            t1.end_fill()
+            t1.hideturtle()
+    '''
+    初始化
+    '''
+    t1.setup(1.0,1.0,0,0)
+    t1.bgcolor("black")
+    t1.pencolor("#7ecff1")
+    t1.hideturtle()
+    mt=["#0489D4","#d9f1f1"]
+    mv=["#6cd1ef","#d9f1f1"]
+    for i in range (2):
+        t1.speed(3)
+        t1.delay(0)
+        t1.pensize(2-i*1.2)
+        t1.color(mt[i]) 
+        LMX(0,-70,122.5)
+        LMX(0,-100,175)
+        t1.pensize(3-i*1.6)
+        t1.color(mv[i]) 
+        LMX(0,-200,350)
+        LMX(0,-220,385)
+    nc=["#94d5f0","#acdefa"]
+    for i in range(2):
+        t1.speed(13)
+        t1.pensize(3-i*1.5)
+        t1.pencolor(nc[i])
+        yuan(220+i)
+        yuan(250+i)
+        yuan(258+i)
+        t1.pensize(1)
+        t1.pencolor("#389bc8")
+        t1.speed(6)
+        yuan(100+i)
+        yuan(110+i)
+        yuan(35+i)
+        yuan(30+i)
+    t.sleep(0.5)
+    t1.speed(5)
+    sixy(86,155,40)
+    BT=["#54B6D8","#f0efeb"]
+    t1.speed(10)
+    for i in range(2):
+        t1.speed(5)
+        t1.delay(0)
+        t1.color(BT[i])
+        t1.pensize(3-i*1.6)
+        t1.seth(-12)
+        lbx(-123,-135.88)
+        t1.seth(0)
+        lbx(-90,-155.88)
+        t1.seth(12)
+        lbx(-57,-175.88)
+    t1.speed(10)
+    t1.pencolor("#5daed9")
+    t1.pensize(1.3)
+    ZR=[-150,30,300,120]
+    for i in range(4):
+        t1.seth(ZR[i])
+        yue(0,53,50)
+    t1.delay(0)
+    t1.pu()
+    t1.goto(-400, 20)
+    t1.pd()
+    xingzuo(235,15,0)
+    for i in range(2):
+        t1.pensize(10-7.7*i)
+        t1.speed(12)
+        t1.pu()
+        t1.goto(0, -254+i*34)
+        t1.pd() 
+        t1.pencolor("black")
+        t1.seth(0)
+        t1.circle(254-i*34)
+    t.sleep(2)
+    t1.speed(35)
+    for i in range(15):
+        t1.pu()
+        t1.goto(0,-240-i*4.5)
+        t1.pd()
+        t1.pencolor("black")
+        t1.pensize(35)
+        t1.seth(0)
+        t1.circle(240+i*4.5)
+        xingzuo(240+i*4.5,17,i)
+    t.sleep(1.5)
+    t1.speed(15)
+    t1.pencolor("yellow")
+    t1.pensize(0.7)
+    xingdui(30)
+    t.sleep(2)
+    t1.reset()
+    CL=['#7ecff1','yellow','#7ecff1','yellow']
+    j=0
+    for i in range(30,91,20):
+        t1.delay(0)
+        t1.pensize(0.1*(i-20)/10+0.7)
+        t1.pencolor(CL[j])
+        t1.speed(30)
+        xingdui(i)
+        t.sleep(1)
+        j=j+1
+        t1.reset()
+    j=0
+    t1.pencolor("yellow")
+    t1.pensize(1.4)
+    t1.speed(30)
+    xingdui(90)
+    t1.speed(50)
+    t1.delay(0)
+    lx(280,8,0,0)
+    t.sleep(1)
+    lx(340,24,0,1)
+    t.sleep(1)
+    lx(400,8,0,0)
+    t.sleep(1.5)
+    lx(280,8,0,2)
+    lx(340,24,0,2)
+    lx(400,8,0,2)
+    t.sleep(0.75)
+    for i in range(3):
+        t1.speed(150+i*100)
+        t1.delay(0)
+        lx(380+i*150,12,0,1)
+        lx(380+i*150,6,0,0)
+    t1.speed(20)
+    stars(51)
+    stars(100)
+    stars(301)
+    t1.pu()
+    t1.home()
+    t1.pd()
+    tailand(114514)
+    t1.home()
+    t1.pencolor('blue')
+    t1.speed(100)
+    t1.hideturtle()
+    for i in range(92):
+        t1.forward(i)
+        t1.left(91)
+    t1.ht()
+    t1.speed(0) 
+    t1.pensize(2)
+    t1.color(1,1,1)
+    r = 10
+    t1.pu()
+    t1.goto(0,-r)
+    t1.pd()
+    acc_ext  = 0
+    for _ in range(1000):
+        t1.color(random.choice([(0,0,0),(1,1,1)]))
+        ext = random.random() * 90
+        t1.circle(r, ext)
+        acc_ext += ext
+        if acc_ext > 360:
+          acc_ext  = 0
+          r+= 3
+          t1.pu()
+          t1.goto(0,-r)
+          t1.seth(0)
+          t1.pd()
+    t1.home()
+    t1.pencolor('blue')
+    t1.write('修改成功',align="center",font=("宋体",20,"normal"))
+    t.sleep(3)
+    t1.reset()
+    print('修改已完成')
+    os.startfile('.\ikun\\num2.txt')
+
 def sqrt(m):
     x0 = m/2 #初始点，也可以是别的值
     x1 = x0/2 + m/(x0*2)
@@ -85,7 +466,7 @@ def CN_fanti_allthing(qwe):
         print('本文件夾有',(a09876)/1024/1024/1024,'個 GB 大')
         del a12345,a09876,file_name,m1,m2,m3,m4,m5,i,scale,start,dur,a,b,c
         gc.collect()
-        hh.Print()
+        Print()
         print('dingdong,開機成功')
     fileeee(1)
     num1='114514'
@@ -525,7 +906,7 @@ def CN_fanti_allthing(qwe):
                         print('密碼錯誤')
                         num10=input('boss,請輸入原始密碼:')
                     num2=input('請輸入新密碼:')
-                    xiugou.xiugay(553717805371)
+                    xiugay(553717805371)
                     with open('.\ikun\\num2.txt','w') as f2:f2.write(num2)                    
                     print('boss您的新密碼是{0}'.format(num2))
                 else:print('error')
@@ -591,7 +972,7 @@ def CN_allthing(qwe):
         print('本文件夹有',(a09876)/1024/1024/1024,'个 GB 大')
         del a12345,a09876,file_name,m1,m2,m3,m4,m5,i,scale,start,dur,a,b,c
         gc.collect()
-        hh.Print()
+        Print()
         print('dingdong,开机成功')
     fileeee(1)
     num1='114514'
@@ -1031,7 +1412,7 @@ def CN_allthing(qwe):
                         print('密码错误')
                         num10=input('boss,请输入原始密码:')
                     num2=input('请输入新密码:')
-                    xiugou.xiugay(553717805371)
+                    xiugay(553717805371)
                     with open('.\ikun\\num2.txt','w') as f2:f2.write(num2)                    
                     print('boss您的新密码是{0}'.format(num2))
                 else:print('error')
@@ -1097,7 +1478,7 @@ def US_allthing(qwe):
         print('large(GB)',(a09876)/1024/1024/1024)
         del a12345,a09876,file_name,m1,m2,m3,m4,m5,i,scale,start,dur,a,b,c
         gc.collect()
-        hh.Print()
+        Print()
         print('Welcome!')
     fileeee(1)
     num1='114514'
@@ -1509,7 +1890,7 @@ def US_allthing(qwe):
                         print('Password error')
                         num10=input('boss,Please enter your original password:')
                     num2=input('Please enter a new password:')
-                    xiugou.xiugay(553717805371)
+                    xiugay(553717805371)
                     with open('.\ikun\\num2.txt','w') as f2:f2.write(num2)                    
                     print('boss~your new password is :{0}'.format(num2))
                 else:print('error')
